@@ -1,5 +1,6 @@
 ui <- tagList(
   navbarPage(
+    position = "fixed-top",
     theme = shinythemes::shinytheme("flatly"),
     title = div(img(src='iconohorizontal.png',style="margin-top: -14px; padding-right:0px; padding-left:0px; padding-bottom:10px", height = 60, width = 100)),
     windowTitle = "LipidMS",
@@ -7,26 +8,41 @@ ui <- tagList(
     tabPanel(title = "Data import", value = "tab1",
              h4("LipidMS: Lipid annotation for LC-MS/MS data"),
              tags$hr(),
-             mainPanel(widht = 4,
-                       textInput("jobname", "Job Name",
+             sidebarPanel(width = 3,
+                          fluidRow(textInput("jobname", "Job Name",
                                  value = paste("Job", as.character(Sys.Date()), sep = "_")),
-                       fileInput("file1", "Choose mzXML File/s",
+                                 style = "margin: 20px 0px 0px 0px"),
+                          fluidRow(radioButtons("analysis", "How do you want to process your data?",
+                                    choices = c("Batch Processing" = "batch",
+                                                "Single Sample Processing" = "single"),
+                                    selected = "batch"),
+                                   style = "margin: 20px 0px 0px 0px"),
+                          fluidRow(radioButtons("sI_polarity", "Polarity",
+                                                       choices = c("Positive" = "positive",
+                                                                   "Negative" = "negative"),
+                                                       selected = "positive"),
+                                   style = "margin: 20px 0px 0px 0px"),
+                          fluidRow(fileInput("file1", "Choose mzXML File/s",
                                  multiple = TRUE,
                                  accept = c("text/plain",
                                             ".mzXML")),
-                       radioButtons("sI_acquisitionmode", "Acquisition Mode",
-                                    choices = c(DIA = "DIA",
-                                                DDA = "DDA"),
-                                    selected = "DIA"),
-                       radioButtons("sI_polarity", "Polarity",
-                                    choices = c("Positive" = "positive",
-                                                "Negative" = "negative"),
-                                    selected = "positive"),
-                       actionButton("JumpTo2", "Next >", width = "100px", 
-                                    style="margin:40px 0px")
-            )
+                                 style = "margin: 20px 0px 0px 0px"),
+                          fluidRow(fileInput("metadata", "Metadata csv file",
+                                 multiple = TRUE,
+                                 accept = c("text/plain",
+                                            ".csv")),
+                                 h6(em("It must be a csv file with 3 columns:\n",
+                                       "sample (mzXML file names),\n",
+                                       "acquisitionmode (MS, DIA or DDA) and\n",
+                                       "sampletype (QC, group1, group2, etc.)"), style = "color:grey"),
+                                 style = "margin: 20px 0px 0px 0px"),
+                          tags$hr(style = "border-color: white"),
+                          fluidRow(actionButton("JumpTo2", "Next >", width = "100px"),
+                                   style = "margin: 20px 0px 0px 0px")
+            ),
+            mainPanel(tableOutput("metadata"))
     ),
-    tabPanel(title = "Data processing", value = "tab2",
+    tabPanel(title = "Peak-picking", value = "tab2",
              h4("LipidMS: Lipid annotation for LC-MS/MS data"),
              tags$hr(),
              tags$head(
@@ -37,16 +53,16 @@ ui <- tagList(
                position="left",
                fluidRow(column(6, h5(strong("dmzagglom (in ppm)")),
                                h6(em("m/z tolerance used for partitioning and clustering. 5 by default."), style = "color:grey")),
-                        column(3, numericInput("dmzagglom_ms1", "MS1", value = 5, min = 0, max = 100, step = 1)),
-                        column(3, numericInput("dmzagglom_ms2", "MS2", value = 5, min = 0, max = 100, step = 1))),
+                        column(3, numericInput("dmzagglom_ms1", "MS1", value = 15, min = 0, max = 100, step = 1)),
+                        column(3, numericInput("dmzagglom_ms2", "MS2", value = 15, min = 0, max = 100, step = 1))),
                fluidRow(column(6, h5(strong("drtagglom (in seconds)")),
                                h6(em("rt window used for partitioning (in seconds). 25 by default."), style = "color:grey")),
-                        column(3, numericInput("drtagglom_ms1", "MS1", value = 25, min = 0, max = 500, step = 1)),
-                        column(3, numericInput("drtagglom_ms2", "MS2", value = 25, min = 0, max = 500, step = 1))),
+                        column(3, numericInput("drtagglom_ms1", "MS1", value = 500, min = 0, max = 1000, step = 1)),
+                        column(3, numericInput("drtagglom_ms2", "MS2", value = 500, min = 0, max = 1000, step = 1))),
                fluidRow(column(6, h5(strong("drtclust (in seconds)")),
                                h6(em("rt window used for clustering (in seconds). 25 by default."), style = "color:grey")),
-                        column(3, numericInput("drtclust_ms1", "MS1", value = 25, min = 0, max = 500, step = 1)),
-                        column(3, numericInput("drtclust_ms2", "MS2", value = 25, min = 0, max = 500, step = 1))),
+                        column(3, numericInput("drtclust_ms1", "MS1", value = 100, min = 0, max = 1000, step = 1)),
+                        column(3, numericInput("drtclust_ms2", "MS2", value = 200, min = 0, max = 1000, step = 1))),
                fluidRow(column(6, h5(strong("minpeak")),
                                h6(em("minimum number of measurements required for a peak. By default, 5 for MS1 and 4 for MS2."), style = "color:grey")),
                         column(3, numericInput("minpeak_ms1", "MS1", value = 5, min = 1, max = 25, step = 1)),
@@ -55,7 +71,7 @@ ui <- tagList(
                                h6(em("minimum intensity of a peak. By default, 1000 for MS1 and 100 for MS2."), style = "color:grey")),
                         column(3, numericInput("minint_ms1", "MS1", value = 1000, min = 0, max = 1e5, step = 1)),
                         column(3, numericInput("minint_ms2", "MS2", value = 100, min = 0, max = 1e5, step = 1))),
-               fluidRow(column(6, h5(strong("grtgap (in seconds)")),
+               fluidRow(column(6, h5(strong("drtgap (in seconds)")),
                                h6(em("maximum rt gap length to be filled. 5 by default."), style = "color:grey")),
                         column(3, numericInput("drtgap_ms1", "MS1", value = 5, min = 0, max = 30, step = 1)),
                         column(3, numericInput("drtgap_ms2", "MS2", value = 5, min = 0, max = 30, step = 1))),
@@ -66,7 +82,7 @@ ui <- tagList(
                fluidRow(column(6, h5(strong("drtmaxpeak (in seconds)")),
                                h6(em("maximum rt width of a single peak. 100 by default."), style = "color:grey")),
                         column(3, numericInput("drtmaxpeak_ms1", "MS1", value = 100, min = 0, max = 500, step = 1)),
-                        column(3, numericInput("drtmaxpeak_ms2", "MS2", value = 100, min = 0, max = 500, step = 1))),
+                        column(3, numericInput("drtmaxpeak_ms2", "MS2", value = 200, min = 0, max = 500, step = 1))),
                fluidRow(column(6, h5(strong("maxeicpeaks")),
                                h6(em("maximum number of peaks within one EIC. By default, 5 for 10 and 3 for MS2."), style = "color:grey")),
                         column(3, numericInput("recurs_ms1", "MS1", value = 5, min = 1, max = 50, step = 1)),
@@ -91,12 +107,57 @@ ui <- tagList(
                                h6(em("rt window for isotope matching. 5 by default."), style = "color:grey")),
                         column(3, numericInput("drtIso_ms1", "MS1", value = 5, min = 0, max = 100, step = 1)),
                         column(3, numericInput("drtIso_ms2", "MS2", value = 5, min = 0, max = 100, step = 1))),
+               tags$hr(),
                fluidRow(actionButton("GoBackTo1", "< Previous", width = "100px", 
                                      style="margin:40px 0px"), 
                         actionButton("JumpTo3", "Next >", width = "100px", 
                                      style="margin:40px 0px"))
              )),
-    tabPanel(title = "Annotation", value = "tab3",
+    tabPanel(title = "Batch processing", value = "tab3",
+             h4("LipidMS: Lipid annotation for LC-MS/MS data"),
+             tags$hr(),
+             tags$head(
+               tags$style(HTML("input[type=\"number\"] {
+                               height: 35px; font-size:11px
+                               }"))),
+             mainPanel(fluidRow(column(6, h5(strong("dmzalign")),
+                                       h6(em("mass tolerance between peak groups for alignment (in ppm). 5 by default."), style = "color:grey")),
+                                column(3, numericInput("dmzalign", "", value = 5, min = 0, max = 100, step = 1))),
+                       fluidRow(column(6, h5(strong("drtalign")),
+                                       h6(em("maximum rt distance between peaks for alignment (in seconds). 30 by default."), style = "color:grey")),
+                                column(3, numericInput("drtalign", "", value = 30, min = 0, max = 200, step = 1))),
+                       fluidRow(column(6, h5(strong("span")),
+                                       h6(em("span parameter for loess rt smoothing. 0.4 by default."), style = "color:grey")),
+                                column(3, numericInput("span", "", value = 0.4, min = 0, max = 1, step = 0.05))),
+                       fluidRow(column(6, h5(strong("minsamplesfracalign")),
+                                       h6(em("minimum samples fraction represented in each cluster used for alignment. 0.75 by default."), style = "color:grey")),
+                                column(3, numericInput("minsamplesfracalign", "", value = 0.75, min = 0, max = 1, step = 0.05))),
+                       fluidRow(column(6, h5(strong("dmzgroup")),
+                                       h6(em("mass tolerance between peak groups for grouping (in ppm). 5 by default."), style = "color:grey")),
+                                column(3, numericInput("dmzgroup", "", value = 5, min = 0, max = 100, step = 1))),
+                       fluidRow(column(6, h5(strong("drtagglomgroup")),
+                                       h6(em("maximum rt distance in mz partitions for grouping (in seconds). 30 by default. It shouldn't be smaller than drtgroup."), style = "color:grey")),
+                                column(3, numericInput("drtagglomgroup", "", value = 30, min = 0, max = 200, step = 1))),
+                       fluidRow(column(6, h5(strong("drtgroup")),
+                                       h6(em("maximum rt distance between peaks for grouping (in seconds). 30 by default."), style = "color:grey")),
+                                column(3, numericInput("drtgroup", "", value = 15, min = 0, max = 200, step = 1))),
+                       fluidRow(column(6, h5(strong("minsamplesfracgroup")),
+                                       h6(em("minimum samples fraction represented in each cluster used for grouping. 0.25 by default."), style = "color:grey")),
+                                column(3, numericInput("minsamplesfracgroup", "", value = 0.25, min = 0, max = 1, step = 0.05))),
+                       fluidRow(column(6, h5(strong("parallel")),
+                                       h6(em("parallelize processing. FALSE by default."), style = "color:grey")),
+                                column(3, selectInput("parallel", "", choices = list("TRUE" = TRUE, "FALSE" = FALSE), 
+                                                      selected = FALSE))),
+                       fluidRow(column(6, h5(strong("ncores")),
+                                       h6(em("number of cores to be used in case parallel is TRUE. 2 by default."), style = "color:grey")),
+                                column(3, numericInput("ncore", "", value = 2, min = 0, max = 50, step = 1))),
+                       tags$hr(),
+                       fluidRow(actionButton("GoBackTo2", "< Previous", width = "100px", 
+                                             style="margin:40px 0px"), 
+                                actionButton("JumpTo4", "Next >", width = "100px", 
+                                             style="margin:40px 0px"))
+             )),
+    tabPanel(title = "Annotation", value = "tab4",
              h4("LipidMS: Lipid annotation for LC-MS/MS data"),
              tags$hr(),
              mainPanel(fluidRow(column(6, h5(strong("dmzprecursor")),
@@ -151,36 +212,46 @@ ui <- tagList(
                                                                           "LPS", "PC", "PE", "PG", "PI", "PS", "Sph",
                                                                           "SphP", "Cer", "CL", "BA")))),
                        tags$hr(),
-                       fluidRow(actionButton("GoBackTo2", "< Previous", width = "100px", 
+                       fluidRow(actionButton("GoBackTo3", "< Previous", width = "100px", 
                                              style="margin:40px 0px"), 
-                                actionButton("JumpTo4", "Next >", width = "100px", 
+                                actionButton("JumpTo5", "Next >", width = "100px", 
                                              style="margin:40px 0px"))
                        )),
-    tabPanel(title = "Run", value = "tab4",
+    tabPanel(title = "Run", value = "tab5",
              h4("LipidMS: Lipid annotation for LC-MS/MS data"),
-             sidebarPanel(width = 2,
-                          fluidRow(h5("\nRun your job: ")),
+             tags$hr(),
+             sidebarPanel(width = 3,
+                          fluidRow(h5("\nRun your job: "),
+                                   style = "margin: 20px 0px 0px 0px"),
                           fluidRow(actionButton("do", "Run", 
-                                                style="color: #fff; background-color: #336666; border-color: #000")),
-                          textOutput("txt_result"),
-                          tags$hr(),
+                                                style="color: #fff; background-color: #669999; border-color: #000"),
+                                   style = "margin: 20px 0px 0px 0px"),
+                          tags$hr(style = "border-color: white"),
                           fluidRow(h5("\nDownload your results: "),
-                                   h6(em("(Wait until your results show up on the main panel)"))),
+                                   h6(em("(Wait until your results show up on the main panel)")),
+                                   style = "margin: 20px 0px 0px 0px"),
                           fluidRow(downloadButton("downloadSummary", "Summary Tables", 
-                                                  style="color: #fff; background-color: #336666; border-color: #000")),
-                          tags$hr(),
+                                                  style="color: #fff; background-color: #669999; border-color: #000"),
+                                   style = "margin: 20px 0px 0px 0px"),
                           fluidRow(downloadButton("downloadPeaklist", "Annotated Peaklists", 
-                                                  style="color: #fff; background-color: #336666; border-color: #000")),
-                          tags$hr(),
+                                                  style="color: #fff; background-color: #669999; border-color: #000"),
+                                   style = "margin: 20px 0px 0px 0px"),
+                          fluidRow(downloadButton("downloadBatchResults", "Batch Results (if applied)", 
+                                                  style="color: #fff; background-color: #669999; border-color: #000"),
+                                   style = "margin: 20px 0px 0px 0px"),
                           fluidRow(downloadButton("downloadPlots", "Plots", 
-                                                  style="color: #fff; background-color: #336666; border-color: #000")),
-                          fluidRow(actionButton("GoBackTo3", "< Previous", width = "100px", 
-                                       style="margin:40px 0px"))
+                                                  style="color: #fff; background-color: #669999; border-color: #000"),
+                                   style = "margin: 20px 0px 0px 0px"),
+                          tags$hr(style = "border-color: white"),
+                          fluidRow(actionButton("GoBackTo4", "< Previous", width = "100px", 
+                                       style="margin:40px 0px"),
+                                   style = "margin: 20px 0px 0px 0px")
              ),
              mainPanel(
                tabsetPanel(type = "tabs",
-                           tabPanel("Summary Tables", tableOutput("summaryTable")),
-                           tabPanel("Annotated Peaklists", tableOutput("annotatedPeaklist"))
+                           tabPanel("Summary Tables Annotation", tableOutput("summaryTable")),
+                           tabPanel("Annotated Peaklists", tableOutput("annotatedPeaklist")),
+                           tabPanel("Batch Results", tableOutput("features"))
                            )
              ))
   )
